@@ -25,6 +25,13 @@
    site ftp.antaire.com in antaire/src, file dmalloc/dmalloc.tar.gz.  */
 #undef WITH_DMALLOC
 
+/* Define if we have to include std/bastring.cc in order to get string
+   symbols for types other than char defined */
+#undef NEED_BASTRING_CC
+
+/* Define if we must explicitly instantiate wstring::nilRep */
+#undef NEED_EXPLICIT_UNISTRING_NILREP
+
 /* Keep autoheader happy... ;-)  */
 #undef GNUFLAGS
 #undef TEMPLATEFLAGS
