@@ -1,11 +1,15 @@
 // Copyright (c) 1996  David Engberg  All rights reserved
-// $Id: CommandLine.h,v 1.1 1996/01/08 03:02:32 geppetto Exp $
+// $Id: CommandLine.h,v 1.2 1998/04/12 22:14:44 geppetto Exp $
 #ifndef _CommandLine_h
 #define _CommandLine_h
+#ifdef __GNUG__
 #pragma interface
+#endif
 
 #include <deque>
-#include "string.h"
+#include "cppstring.h"
+
+using namespace std;
 
 //
 //  Class name : CCommandLine
