@@ -1,12 +1,16 @@
 // Copyright (c) 1996  David Engberg  All rights reserved
-// $Id: FilePath.h,v 1.4 1997/06/13 18:18:49 geppetto Exp $
+// $Id: FilePath.h,v 1.5 1998/04/12 22:14:44 geppetto Exp $
 #ifndef _FilePath_h
 #define _FilePath_h
+#ifdef __GNUG__
 #pragma interface
+#endif
 
 #include <string>
 #include <deque>
 
+using namespace std;
+
 //
 //  Class name : CFilePath
 //  Description : Represents a Unix file path
@@ -28,8 +32,6 @@ public:
   bool IsExecutable() const;
   bool ContainsLinks() const;
 
-  int ListDirectoryContents(deque<string>& listToFill) const;
-
   bool MakeDirectory() const;
 
   string GetString() const;
