@@ -1,11 +1,15 @@
 // Copyright (c) 1997  David Engberg  All rights reserved
-// $Id: InnerClassesTable.h,v 1.1 1997/11/10 00:47:24 geppetto Exp $
+// $Id: InnerClassesTable.h,v 1.2 1998/04/12 22:14:44 geppetto Exp $
 #ifndef _InnerClassesTable_h
 #define _InnerClassesTable_h
+#ifdef __GNUG__
 #pragma interface
+#endif
 
 #include "JavaAttribute.h"
-class ostream;
+#include <list>
+
+using namespace std;
 
 //
 //  Class name : CInnerClassesTable
@@ -34,7 +38,7 @@ public:
     CJavaAccessFlags fAccessFlags;
     unicode_string fOuterName;
   } InnerClassInfo;
-  typedef vector<InnerClassInfo*> InnerClassTable;
+  typedef list<InnerClassInfo*> InnerClassTable;
 
   unsigned long Size() const { return fInnerClasses.size(); }
   InnerClassTable::const_iterator InnerClassesBegin() const;
