@@ -1,11 +1,14 @@
 // Copyright (c) 1996  David Engberg  All rights reserved
-// $Id: JavaAccessFlags.h,v 1.3 1996/07/12 20:42:34 geppetto Exp $
+// $Id: JavaAccessFlags.h,v 1.4 1998/04/12 22:14:44 geppetto Exp $
 #ifndef _JavaAccessFlags_h
 #define _JavaAccessFlags_h
+#ifdef __GNUG__
 #pragma interface
+#endif
 
 #include <string>
-class ostream;
+
+using namespace std;
 
 //
 //  Class name : CJavaAccessFlags
