@@ -1,12 +1,13 @@
 // Copyright (c) 1996  David Engberg  All rights reserved
-// $Id: JavaAttribute.h,v 1.4 1997/06/13 18:18:49 geppetto Exp $
-#pragma interface
+// $Id: JavaAttribute.h,v 1.5 1998/04/12 22:14:44 geppetto Exp $
 #ifndef _JavaAttribute_h
 #define _JavaAttribute_h
+#ifdef __GNUG__
+#pragma interface
+#endif
 
 #include "dynamic_cast.h"
 #include "JavaClassFile.h"
-class ostream;
 
 //
 //  Class name : CJavaAttribute
