@@ -1,22 +1,23 @@
 // Copyright (c) 1995  David Engberg  All rights reserved
-// $Id: JavaClassFile.h,v 1.11 1997/11/10 00:47:24 geppetto Exp $
+// $Id: JavaClassFile.h,v 1.12 1998/04/12 22:14:44 geppetto Exp $
 #ifndef _JavaClassFile_h
 #define _JavaClassFile_h
+#ifdef __GNUG__
 #pragma interface
+#endif
 
 #include "JavaConstant.h"
 #include "JavaFieldInfo.h"
 #include "JavaMethodInfo.h"
 #include "JavaMethodSignature.h"
 #include "JavaAccessFlags.h"
+#include "long64.h"
 #include <vector>
 #include <map>
 class CJavaSourceFileAttribute;
 class CCompiler;
 class CInnerClassesTable;
 class CJavaMethodInfo;
-class ostream;
-class istream;
 
 typedef map<CJavaFieldSignature, const CJavaFieldInfo*, less<CJavaFieldSignature> > FieldTable;
 typedef map<CJavaMethodSignature, const CJavaMethodInfo*, less<CJavaMethodSignature> > MethodTable;
@@ -89,7 +90,7 @@ public:
 
   void DisassembleClass(ostream& toStream) const;
   void Compile(ostream& toStream);
-  JavaConstantIndex AddLongConstant(unsigned long long doubleLong);
+  JavaConstantIndex AddLongConstant(unsigned long64 doubleLong);
   JavaConstantIndex AddIntegerConstant(unsigned long integerValue);
   JavaConstantIndex AddFloatConstant(float value);
   JavaConstantIndex AddDoubleConstant(double value);
