@@ -1,11 +1,12 @@
 // Copyright (c) 1995  David Engberg  All rights reserved
-// $Id: JavaExceptionsTable.h,v 1.3 1996/07/12 20:42:34 geppetto Exp $
+// $Id: JavaExceptionsTable.h,v 1.4 1998/04/12 22:14:44 geppetto Exp $
 #ifndef _JavaExceptionsTable_h
 #define _JavaExceptionsTable_h
+#ifdef __GNUG__
 #pragma interface
+#endif
 
 #include "JavaAttribute.h"
-class ostream;
 
 //
 //  Class name : CJavaExceptionsTable
