@@ -1,14 +1,16 @@
-// $Id: JavaFieldInfo.h,v 1.6 1997/06/13 18:18:49 geppetto Exp $
+// $Id: JavaFieldInfo.h,v 1.7 1998/04/12 22:14:44 geppetto Exp $
 // Copyright (c) 1995  David Engberg  All rights reserved
 #ifndef _JavaFieldInfo_h
 #define _JavaFieldInfo_h
+#ifdef __GNUG__
+#pragma interface
+#endif
 
 #include "JavaFieldSignature.h"
 #include "JavaAccessFlags.h"
 #include "JavaConstant.h"
 class CJavaConstantValueAttribute;
 class CJavaClassFile;
-class ostream;
 
 //
 //  Class name : CJavaFieldInfo
