@@ -1,15 +1,16 @@
-// $Id: JavaMethodInfo.h,v 1.6 1997/06/13 18:18:49 geppetto Exp $
+// $Id: JavaMethodInfo.h,v 1.7 1998/04/12 22:14:44 geppetto Exp $
 // Copyright (c) 1995  David Engberg  All rights reserved
 #ifndef _JavaMethodInfo_h
 #define _JavaMethodInfo_h
+#ifdef __GNUG__
 #pragma interface
+#endif
 
 #include "JavaClassFile.h"
 #include "JavaMethodSignature.h"
 #include "JavaAccessFlags.h"
 class CJavaCodeAttribute;
 class CJavaExceptionsTable;
-class ostream;
 class CCompiler;
 
 //
