@@ -1,11 +1,13 @@
-// $Id: JavaMethodSignature.h,v 1.5 1997/11/10 00:47:24 geppetto Exp $
+// $Id: JavaMethodSignature.h,v 1.6 1998/04/12 22:14:44 geppetto Exp $
 // Copyright (c) 1995  David Engberg  All rights reserved
 #ifndef _JavaMethodSignature_h
 #define _JavaMethodSignature_h
+#ifdef __GNUG__
+#pragma interface
+#endif
 
 #include "JavaTypeSignature.h"
-#include <deque.h>
-class ostream;
+#include <deque>
 
 //
 //  Class name : CJavaMethodSignature
