@@ -1,5 +1,5 @@
 // Copyright (c) 1995  David Engberg  All rights reserved
-// $Id: Expression.h,v 1.14 1997/11/10 00:48:06 geppetto Exp $
+// $Id: Expression.h,v 1.15 1998/05/23 18:51:15 geppetto Exp $
 #ifndef _Expression_h
 #define _Expression_h
 #pragma interface
@@ -539,6 +539,7 @@ private:
   Type fType;
 };
 
+
 //
 //  Class name : CInstanceof
 //  Description : This is used for the expression  (foo instanceof String)
@@ -559,4 +560,60 @@ private:
   CJavaTypeSignature fToType;
 };
 
+
+//
+//  Class name : CClassInstance
+//  Description : This type of expression is used to generate a Class object
+//    for a given type.  In Java, this looks like this:
+//       Class c =    String.class   ;
+//
+class CClassInstance : public CExpression {
+  DynamicCastDeclarations;
+public:
+  CClassInstance(const CJavaTypeSignature& type);
+  CClassInstance(const CClassInstance& source);
+  virtual ~CClassInstance();
+  virtual CExpression* Clone() const { return new CClassInstance(*this); }
+  virtual CCompileError* GenerateCode(CCodeSequence& code,
+		   CCompileContext& context, unsigned short& stackUsed,
+	           bool isStatement = false);
+protected:
+  virtual CCompileError* HandleEvaluateType(CCompileContext& context,
+					    CJavaTypeSignature& setType);
+private:
+  CJavaTypeSignature fClassType;
+  unicode_string fSyntheticFieldName;
+};
+
+
+//
+//  Class name : COuterThis
+//  Description : This type of expression is used to generate the 'this'
+//    for an enclosing class scope.  This was introduced in JDK1.1, and looks
+//    like this:
+//       class C1 {
+//          int x;
+//          class C2 {
+//            C2() {   x =  C1.this   .x;   }
+//          }
+//       }
+//
+class COuterThis : public CExpression {
+  DynamicCastDeclarations;
+public:
+  COuterThis(const CJavaTypeSignature& type);
+  COuterThis(const COuterThis& source);
+  virtual ~COuterThis();
+  virtual CExpression* Clone() const { return new COuterThis(*this); }
+  virtual CCompileError* GenerateCode(CCodeSequence& code,
+		   CCompileContext& context, unsigned short& stackUsed,
+	           bool isStatement = false);
+protected:
+  virtual CCompileError* HandleEvaluateType(CCompileContext& context,
+					    CJavaTypeSignature& setType);
+private:
+  CJavaTypeSignature fOuterType;
+  CExpression* fDelegate;
+};
+
 #endif
