@@ -1,5 +1,5 @@
 // Copyright (c) 1996  David Engberg  All rights reserved
-// $Id: IntermediateFunction.h,v 1.2 1996/01/08 03:03:38 geppetto Exp $
+// $Id: IntermediateFunction.h,v 1.6 1997/11/10 00:48:06 geppetto Exp $
 #ifndef _IntermediateFunction_h
 #define _IntermediateFunction_h
 #pragma interface
@@ -9,6 +9,7 @@
 #include "JavaAccessFlags.h"
 #include "JavaFieldSignature.h"
 #include "unicode_string.h"
+#include "VariableDeclaration.h"
 class CCompiler;
 class CIntermediateClass;
 class CCompoundStatement;
@@ -24,20 +25,30 @@ class CCompoundStatement;
 class CIntermediateFunction {
   friend class CIntermediateClass;
   friend class CCompiler;
-protected:
+public:
   CIntermediateFunction(const CJavaMethodSignature& signature,
 			const CJavaAccessFlags& modifiers,
-			deque<CJavaFieldSignature>* adoptParameters,
-			deque<unicode_string>* adoptThrows);
+			deque<unicode_string>* adoptThrows,
+			unsigned long startLineNumber,
+			bool deprecated = false);
   ~CIntermediateFunction();
   
+  unsigned short GetLocalVariableLocation(unsigned short from) const;
+
 private:
   CJavaMethodSignature fSignature;
   CJavaAccessFlags fAccessFlags;
-  deque<CJavaFieldSignature> fParameters;
   deque<unicode_string> fThrows;
   unsigned long fMaxLocalVariables;
+  unsigned long fRealParametersSize;
+  unsigned long fSyntheticParametersSize;
   CCompoundStatement* fBlock;
+  unsigned long fStartLineNumber;
+  unsigned long fEndLineNumber;
+  bool fDeprecated;
+  deque<CIntermediateClass*> fInnerClasses;
+  CJavaMethodInfo* fMethodInfoAlias;
+
 };
 
 #endif
